##MAME Library Builder v2.0#
##Dracrius - Aug 20th 2019##

Write-Output "Welcome to MAME Library Builder"
Write-Output "`n"
Write-Output "Searching for MLB Settings INI's..."
Write-Output "`n"

$ini_list = path [mM][lL][bB].*[sS][eE][tT][tT][iI][nN][gG][sS]\.[iI][nN][iI]
	error = "No MLB *Name* Settings.ini's Located"

Write-Output "Found:"
Write-Output $ini_list	
Write-Output "`n"

foreach ($ini in $ini_list) {
	
	$root_folder = Get text after [mM][aA][mM][eE]\s[rR][oO][oO][tT]\s*=\s* from $ini
		error = "No MAME Root Setting in $ini! The Script will now close automatically in 10s!" 
	$destination_name = Get text after [lL][iI][bB][rR][aA][rR][yY]\s[nN][aA][mM][eE]\s*=\s* from $ini
		error = "No Library Name Setting in $ini! The Script will now close automatically in 10s!"
	$destination_folder = "$destination_name $root_folder"
	
	Write-Output "Beginning to build $destination_folder Library"
	Write-Output "`n"
	Write-Output "Getting INI Settings..."

	$folder_list = Get lines between  \[[fF][oO][lL][dD][eE][rR][sS]\s[tT][oO]\s[cC][oO][pP][yY]\] and \[[fF][oO][lL][dD][eE][rR][sS]\s[tT][oO]\s[sS][cC][rR][aA][pP]\]
		error = "Folders to Copy section Missing or Out of Order in $ini. INI should be as follows, [Settings], [Folders to Copy], [Folders to Scrap], [ROMs List]! The Script will now close automatically in 10s!"
	$scrap_list = Get lines between \[[fF][oO][lL][dD][eE][rR][sS]\s[tT][oO]\s[sS][cC][rR][aA][pP]\] and \[[rR][oO][mM][sS]\s[lL][iI][sS][tT]\]
		error = "Folders to Scrap section Missing or Out of Order in $ini. INI should be as follows, [Settings], [Folders to Copy], [Folders to Scrap], [ROMs List]! The Script will now close automatically in 10s!"
	$rom_list = Get lines after \[[rR][oO][mM][sS]\s[lL][iI][sS][tT]\]
		error = "ROMs List section Missing or Out of Order in $ini. INI should be as follows, [Settings], [Folders to Copy], [Folders to Scrap], [ROMs List]! The Script will now close automatically in 10s!"
	
	Write-Output "INI Settings Loaded Successfully!"
	Write-Output "`n"
	Write-Output "Beginning with Folders to Copy..."
	
	foreach ($folder in $folder_list) {
        Copy-Item $root_folder\$folder -Destination $destination_folder\$folder -Recurse
	}	
	
	Write-Output "Folder Copying Complete!"
	Write-Output "`n"
	Write-Output "Beginning Scrapping..."
	
	foreach ($scrap in $scrap_list) {
		New-Item -Type dir "$destination_folder\$scrap"
		
		$scrap_folder = "$root_folder\$scrap"
		$scap_destination_folder = "$destination_folder\$scrap"
		
		Write-Output "Scrapping $scrap for Files Matching the ROMs List..."
		
		foreach ($rom in $rom_list) {
			$file_to_copy = Get-ChildItem -Path $scrap_folder -Filter $rom -Recurse -ErrorAction SilentlyContinue -Force | % { $_.FullName}
			if ($file_to_copy) {
				Copy-Item $file_to_copy $scrap_destination_folder
				}
		}
		
		Write-Output "$scrap Complete!"
	}
	
	Write-Output "`n"
	Write-Output "All Scrapping Complete!"
	Write-Output "`n"
	Write-Output "$destination_folder Library Creation Complete!"
	Write-Output "`n"
		
}

Write-Output "All SubLibrary Creation Complete!"
Write-Output "MAME Library Builder will automatically close in 10s..."
Start-Sleep -s 10